Package: meteospain
Title: Access to Spanish Meteorological Stations Services
Version: 0.3.1
Authors@R: 
    c(
      person(given = "Victor",
             family = "Granda", 
             role = c("aut", "cre"),
             email = "victorgrandagarcia@gmail.com",
             comment = c(ORCID = "0000-0002-0469-1991")),
      person(given = "Miquel",
             family = "de Caceres", 
             role = c("ctb"),
             email = "m.caceres@creaf.uab.cat",
             comment = c(ORCID = "0000-0001-7132-2080")),
      person(given = "Aitor",
             family = "Ameztegui", 
             role = c("ctb"),
             email = "aitor.ameztegui@udl.cat",
             comment = c(ORCID = "0000-0003-2006-1559")),
      person(given = "Luis",
             family = "Franco", 
             role = c("ctb")),
      person(given = "Rubén",
             family = "Fernández-Casal", 
             role = c("ctb"))
    )
Description: Access to different Spanish meteorological stations data services and APIs (AEMET, SMC, MG, 
  Meteoclimatic...).
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.3.0)
Suggests: ggforce, ggplot2, keyring, knitr, rmarkdown, testthat (>=
        3.0.0), withr
Imports: assertthat, dplyr (>= 1.0.0), glue, jsonlite, lubridate, purrr
        (>= 1.0.0), rlang, sf, stringr, tidyr, units, xml2, vctrs,
        cachem, cli, httr2, rvest
Config/testthat/edition: 3
Config/testthat/parallel: true
VignetteBuilder: knitr
URL: https://emf-creaf.github.io/meteospain/,
        https://github.com/emf-creaf/meteospain
BugReports: https://github.com/emf-creaf/meteospain/issues
NeedsCompilation: no
Packaged: 2026-01-08 10:35:03 UTC; malditobarbudo
Author: Victor Granda [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0469-1991>),
  Miquel de Caceres [ctb] (ORCID:
    <https://orcid.org/0000-0001-7132-2080>),
  Aitor Ameztegui [ctb] (ORCID: <https://orcid.org/0000-0003-2006-1559>),
  Luis Franco [ctb],
  Rubén Fernández-Casal [ctb]
Maintainer: Victor Granda <victorgrandagarcia@gmail.com>
Repository: CRAN
Date/Publication: 2026-01-08 15:10:08 UTC
Built: R 4.6.0; ; 2026-04-26 19:41:30 UTC; unix
