# Generated by roxygen2: do not edit by hand

export(aemet_options)
export(clear_meteospain_cache)
export(get_meteo_from)
export(get_quota_from)
export(get_stations_info_from)
export(get_variables_from)
export(meteocat_options)
export(meteoclimatic_options)
export(meteogalicia_options)
export(ria_options)
importFrom(rlang,":=")
importFrom(rlang,.data)
